@@ -11,7 +11,8 @@ import {
     TupleOfflineStorageNameService,
     TupleStorageFactoryService,
     TupleStorageFactoryServiceWeb,
-    SqlFactoryService,
+    WebSqlBrowserFactoryService,
+    WebSqlFactoryService,
 } from "@synerty/vortexjs";
 import { staticRoutes } from "./app.routes";
 import { peekRootServices } from "./app.services";
@@ -55,7 +56,10 @@ export function tupleOfflineStorageNameServiceFactory() {
     ],
     providers: [
         { provide: NZ_I18N, useValue: en_US },
-        SqlFactoryService,
+        {
+            provide: WebSqlFactoryService,
+            useClass: WebSqlBrowserFactoryService,
+        },
         {
             provide: TupleStorageFactoryService,
             useClass: TupleStorageFactoryServiceWeb,
